package logfunk

import (
	"io"
	"os"
)

// Logger mimics the log.Logger structure
type Logger struct {
	fun F
}

// NewLogger creates a new log.Logger-compatible Logger wrapping f
func NewLogger(f F) *Logger {
	return &Logger{fun: f}
}

// Fatal mimics log.Logger
func (l *Logger) Fatal(v ...interface{}) {
	l.fun("%v", v)
	os.Exit(1)
}

// Fatalf mimics log.Logger
func (l *Logger) Fatalf(format string, v ...interface{}) {
	l.fun(format, v)
	os.Exit(1)
}

// Fatalln mimics log.Logger
func (l *Logger) Fatalln(v ...interface{}) {
	l.fun("%v\n", v)
	os.Exit(1)
}

// Flags mimics log.Logger
func (l *Logger) Flags() int {
	return 0
}

// Output mimics log.Logger
func (l *Logger) Output(calldepth int, s string) error {
	l.fun("%s", s)
	return nil
}

// Panic mimics log.Logger
func (l *Logger) Panic(v ...interface{}) {
	l.fun("%v", v)
	panic(v)
}

// Panicf mimics log.Logger
func (l *Logger) Panicf(format string, v ...interface{}) {
	l.fun(format, v)
	panic(v)
}

// Panicln mimics log.Logger
func (l *Logger) Panicln(v ...interface{}) {
	l.fun("%v\n", v)
	panic(v)
}

// Prefix mimics log.Logger, returns an empty string
func (l *Logger) Prefix() string {
	return ""
}

// Print mimics log.Logger
func (l *Logger) Print(v ...interface{}) {
	l.fun("%v", v)
}

// Printf mimics log.Logger
func (l *Logger) Printf(format string, v ...interface{}) {
	l.fun(format, v)
}

// Println mimics log.Logger
func (l *Logger) Println(v ...interface{}) {
	l.fun("%v\n", v)
}

// SetFlags mimics log.Logger, but is a nop
func (l *Logger) SetFlags(flag int) {
}

// SetOutput mimics log.Logger, but is a nop
func (l *Logger) SetOutput(w io.Writer) {
}

// SetPrefix mimics log.Logger, but is a nop
func (l *Logger) SetPrefix(prefix string) {
}

// Writer mimics log.Logger, but returns os.Stdout
func (l *Logger) Writer() io.Writer {
	return os.Stdout
}
